@@ -1,8 +1,7 @@
 #include "includes.h"
 #include "spdlog/sinks/systemd_sink.h"
 
-TEST_CASE("systemd", "[all]")
-{
+TEST_CASE("systemd", "[all]") {
     auto systemd_sink = std::make_shared<spdlog::sinks::systemd_sink_st>();
     spdlog::logger logger("spdlog_systemd_test", systemd_sink);
     logger.set_level(spdlog::level::trace);
